abi_decode_event_data

Function abi_decode_event_data 

pub fn abi_decode_event_data(
    event: &Event,
    data: &[u8],
) -> Result<Vec<DynSolValue>>
ABI-decodes the non-indexed parameters (the log data) of an event.

Indexed parameters are stored in the log topics rather than in the data, so they are skipped. This allows decoding the data of a log without knowing its topics.